@@ -63,10 +63,20 @@ class Pipeline(cp.Pipeline):
         self.artifacts[action_name] = cp.Artifact()
         # repository['owner'] MUST match an existing self.connections
         connection_arn = self.connections[repository['owner']]
-        return cpa.BitBucketSourceAction(
+
+        # Include a full git clone https://docs.aws.amazon.com/codepipeline/latest/userguide/action-reference-CodestarConnectionSource.html
+        if 'output_artifact_format' in source_args:
+            if source_args['output_artifact_format'] == 'CODE_ZIP':
+                source_args['code_build_clone_output'] = False
+            else:
+                source_args['code_build_clone_output'] = True
+            del source_args['output_artifact_format']
+        if 'code_build_clone_output' not in source_args:
+            source_args['code_build_clone_output'] = True
+
+        return cpa.CodeStarConnectionsSourceAction(
             connection_arn=connection_arn,
             output=self.artifacts[action_name],
-            code_build_clone_output=True,
             **repository,
             action_name=action_name,
             **source_args
